@@ -17,6 +17,8 @@
 #' Set to NULL to determine automatically based on format
 #' @param format A character. The format of data source, either 'IOHProfiler', 'COCO' or 'TWO_COL"
 #' @param subsampling Logical. Whether *.cdat files are subsampled?
+#' @param full_sampling Logical. Whether the raw (unaligned) FV matrix should be stored.
+#' Currenlt only useful when a correlation plot between function values and parameters should be made
 #'
 #' @return A S3 object 'DataSet'
 #' @export
@@ -25,7 +27,7 @@
 #' info <- read_index_file(file.path(path, 'IOHprofiler_f1_i1.info'))
 #' DataSet(info[[1]])
 DataSet <- function(info, verbose = F, maximization = NULL, format = IOHprofiler,
-                    subsampling = FALSE) {
+                    subsampling = FALSE, full_sampling = FALSE) {
   if (!is.null(info)) {
     path <- dirname(info$datafile)
     suite <- toupper(info$suite)
@@ -70,17 +72,7 @@ DataSet <- function(info, verbose = F, maximization = NULL, format = IOHprofiler
     tdatFile <- file.path(path, paste0(datBaseName, '.tdat'))
     cdatFile <- file.path(path, paste0(datBaseName, '.cdat'))
 
-    # NOTE: preference on data file for the alignment by RT: cdat > tdat > dat
-    if (file.exists(cdatFile))
-      fvFile <- cdatFile
-    else if (file.exists(tdatFile))
-      fvFile <- tdatFile
-    else if (file.exists(datFile))
-      fvFile <- datFile
-    else
-      stop('No datafiles found, please verify the integrity of the chosen files')
-
-    # NOTE: preference on data file for the alignment by FV: dat > tdat > cdat
+    # NOTE: preference on data file from coco: dat > tdat > cdat
     if (file.exists(datFile))
       rtFile <- datFile
     else if (file.exists(tdatFile))
@@ -88,6 +80,8 @@ DataSet <- function(info, verbose = F, maximization = NULL, format = IOHprofiler
     else if (file.exists(cdatFile))
       # TODO: perhaps turn on `subsampling` here as this would take quite some time
       rtFile <- cdatFile
+    else
+      stop('No datafiles found, please verify the integrity of the chosen files')
 
     read_raw <- switch(
       format,
@@ -99,7 +93,6 @@ DataSet <- function(info, verbose = F, maximization = NULL, format = IOHprofiler
     )
 
     RT_raw <- read_raw(rtFile, subsampling)
-    FV_raw <- read_raw(fvFile, subsampling)
 
     if (is.null(maximization)) {
       if (verbose)
@@ -107,14 +100,14 @@ DataSet <- function(info, verbose = F, maximization = NULL, format = IOHprofiler
                 function value progression")
       # TODO: idxTarget should be set depending on the data format
       idxTarget <- 2
-      cond <- unique(lapply(FV_raw, function(FV) FV[1, idxTarget] >= FV[nrow(FV), idxTarget]))
+      cond <- unique(lapply(RT_raw, function(FV) FV[1, idxTarget] >= FV[nrow(FV), idxTarget]))
       if (length(cond) > 1)
         stop('The detected maximization differs in multiple runs')
       maximization <- cond
     }
 
     RT <- align_running_time(RT_raw, format = format, maximization = maximization)
-    FV <- align_function_value(FV_raw, format = format)
+    FV <- align_function_value(RT_raw, format = format)
 
     PAR <- list(
       'by_FV' = RT[names(RT) != 'RT'],
@@ -146,9 +139,9 @@ DataSet <- function(info, verbose = F, maximization = NULL, format = IOHprofiler
     # TODO: clean up these if-statements: Function to set idxTarget and n_data_column?
     # `idxTarget` is a global variable?
     if (format == TWO_COL)
-      finalFV <- set_names(sapply(FV_raw, function(d) d[nrow(d), idxTarget - 1]), NULL)
+      finalFV <- set_names(sapply(RT_raw, function(d) d[nrow(d), idxTarget - 1]), NULL)
     else
-      finalFV <- set_names(sapply(FV_raw, function(d) d[nrow(d), idxTarget]), NULL)
+      finalFV <- set_names(sapply(RT_raw, function(d) d[nrow(d), idxTarget]), NULL)
 
     if (any(finalFV != info$finalFV) && verbose)
       warning('Inconsitent finalFvalue in *.info file and *.dat file')
@@ -159,12 +152,27 @@ DataSet <- function(info, verbose = F, maximization = NULL, format = IOHprofiler
       info$instance <- seq(length(RT_raw))
     }
 
-    do.call(
+    temp <- do.call(
       function(...)
         structure(list(RT = RT, FV = FV, PAR = PAR), class = c('DataSet', 'list'), ...),
       c(info, list(maxRT = maxRT, finalFV = finalFV, format = format,
                    maximization = maximization, suite = suite, ID = info$algId))
     )
+    if (isTRUE(info$constrained) || full_sampling) {
+      FV_raw_mat <- matrix(nrow = nrow(FV), ncol = length(RT_raw))
+      for (idx in seq(length(RT_raw))) {
+        FV_raw_mat[,idx] = RT_raw[[idx]][,2]
+      }
+      temp$FV_raw_mat <- FV_raw_mat
+      attr(temp, 'contains_full_FV') <- TRUE
+    }
+    else {
+      attr(temp, 'contains_full_FV') <- FALSE
+    }
+    if (getOption('IOHanalyzer.function_representation', 'funcId') == 'funcName') {
+      attr(temp, 'funcId') <- attr(temp, 'funcName')
+    }
+    return(temp)
   }
   else
     structure(list(), class = c('DataSet', 'list'))
@@ -251,7 +259,16 @@ c.DataSet <- function(...) {
     align_running_time(RT_raw,
                        format = "TWO_COL",
                        maximization = info$maximization)$RT
-  FV <- align_function_value(RT_raw, format = "TWO_COL")$FV
+  FV_mat <- as.matrix(align_function_value(RT_raw, format = "TWO_COL")$FV)
+
+  if (info$maximization) {
+    FV_mat <- apply(FV_mat, 2, function(x) {x[is.na(x)] <- min(x, na.rm = T); x})
+    FV <- do.call(cbind, lapply(seq(ncol(FV_mat)), function(x) cummax(FV_mat[,x])))
+  }
+  else {
+    FV_mat <- apply(FV_mat, 2, function(x) {x[is.na(x)] <- max(x, na.rm = T); x})
+    FV <- do.call(cbind, lapply(seq(ncol(FV_mat)), function(x) cummin(FV_mat[,x])))
+  }
 
   # TODO: to deal with cases where aligned parameters are present in original DataSets
   PAR <- list('by_FV' = RT[names(RT) != 'RT'],
@@ -503,6 +520,8 @@ get_FV_sample <- function(ds, ...) UseMethod("get_FV_sample", ds)
 #'
 #' @param ds A DataSet or DataSetList object
 #' @param runtime A Numerical vector. Runtimes at which function values are reached
+#' @param include_geom_mean Boolean to indicate whether to include the geometric mean.
+#' Only works in fixed_budget mode. Negative values cause NaN, zeros cause output to be completely 0. Defaults to False.
 #' @param ... Arguments passed to other methods
 #'
 #' @return A data.table containing the function value statistics for each provided
@@ -611,10 +630,43 @@ get_overview <- function(ds, ...) UseMethod("get_overview", ds)
 #' @export
 get_id <- function(ds, ...) UseMethod("get_id", ds)
 
+#' Get function value matrix of the used dataset.
+#'
+#' To be used instead of accessing ds$FV directly, since in the case of constrained
+#' problems, the violation handling should be applied before using the function values
+#' Constraint penalty function should be set in global options, as IOHanalyzer.Violation_Function
+#'
+#'
+#' @param ds The DataSet
+#' @param ... Arguments passed to other methods
+#'
+#' @return The matrix of FV values in the dataset, penalized if applicable.
+#' @examples
+#' get_FV(dsl[[1]])
+#' @export
+get_FV <- function(ds, ...) UseMethod("get_FV", ds)
+
+#' Get runtime matrix of the used dataset.
+#'
+#' To be used instead of accessing ds$RT directly, since in the case of constrained
+#' problems, the violation handling should be applied before using the function values
+#' Constraint penalty function should be set in global options, as IOHanalyzer.Violation_Function
+#'
+#'
+#' @param ds The DataSet
+#' @param ... Arguments passed to other methods
+#'
+#' @return The matrix of FV values in the dataset, penalized if applicable.
+#' @examples
+#' get_RT(dsl[[1]])
+#' @export
+get_RT <- function(ds, ...) UseMethod("get_RT", ds)
+
+
 #' @rdname get_FV_overview
 #' @export
 get_FV_overview.DataSet <- function(ds, ...) {
-  data <- ds$FV
+  data <- get_FV(ds)
   runs <- ncol(data)
   last_row <- data[nrow(data), ]
   budget <- max(attr(ds, 'maxRT'))
@@ -649,7 +701,7 @@ get_FV_overview.DataSet <- function(ds, ...) {
 get_RT_overview.DataSet <- function(ds, ...) {
 
   if (!is.null(attr(ds, "format")) && attr(ds, "format") == NEVERGRAD) {
-    data <- ds$FV
+    data <- get_FV(ds)
     budget <- max(attr(ds, 'maxRT'))
     runs <- ncol(data)
     min_rt <- rownames(data) %>% as.integer %>% min
@@ -657,7 +709,7 @@ get_RT_overview.DataSet <- function(ds, ...) {
   }
 
   else{
-    data <- ds$RT
+    data <- get_RT(ds)
     runs <- ncol(data)
     budget <- max(attr(ds, 'maxRT'))
     min_rt <- min(data, na.rm = T)
@@ -677,12 +729,12 @@ get_RT_overview.DataSet <- function(ds, ...) {
 #' @export
 #'
 get_overview.DataSet <- function(ds, ...) {
-  data <- ds$FV
+  data <- get_FV(ds)
   runs <- ncol(data)
 
   budget <- max(attr(ds, 'maxRT'))
-  if (!is.null(ds$RT) && length(ds$RT) > 0) {
-    max_rt <- max(ds$RT, na.rm = T)
+  if (!is.null(get_RT(ds)) && length(get_RT(ds)) > 0) {
+    max_rt <- max(get_RT(ds), na.rm = T)
     budget <- max(budget, max_rt)
   }
   else max_rt <- budget
@@ -720,7 +772,7 @@ get_overview.DataSet <- function(ds, ...) {
 #' @export
 #'
 get_ERT.DataSet <- function(ds, ftarget, budget = NULL, ...) {
-  data <- ds$RT
+  data <- get_RT(ds)
   if (is.null(budget) || is.na(budget)) maxRT <- attr(ds, 'maxRT')
   else maxRT <- as.numeric(budget)
   algId <- attr(ds, 'algId')
@@ -746,7 +798,7 @@ get_ERT.DataSet <- function(ds, ftarget, budget = NULL, ...) {
 #' @export
 #'
 get_RT_summary.DataSet <- function(ds, ftarget, budget = NULL, ...) {
-  data <- ds$RT
+  data <- get_RT(ds)
   if (is.null(budget) || is.na(budget)) maxRT <- max(attr(ds, 'maxRT'))
   else maxRT <- as.numeric(budget)
   ID <- get_id(ds)
@@ -807,8 +859,12 @@ get_maxRT <- function(ds, ...) UseMethod("get_maxRT", ds)
 #'
 get_maxRT.DataSet <- function(ds, output = 'wide', ...) {
   ID <- get_id(ds)
-  N <- ncol(ds$RT)
-  res <- t(c(ID, attr(ds, 'maxRT'))) %>%
+  N <- ncol(get_RT(ds))
+  maxRT <- attr(ds, 'maxRT')
+  if (length(maxRT) < N) {
+    maxRT <- rep(maxRT, N)
+  }
+  res <- t(c(ID, maxRT)) %>%
     as.data.table %>%
     set_colnames(c('ID', paste0('run.', seq(N))))
 
@@ -825,7 +881,7 @@ get_maxRT.DataSet <- function(ds, output = 'wide', ...) {
 #' @param output A character determining the format of output data.table: 'wide' or 'long'
 #' @export
 get_RT_sample.DataSet <- function(ds, ftarget, output = 'wide', ...) {
-  data <- ds$RT
+  data <- get_RT(ds)
   N <- ncol(data)
   ID <- get_id(ds)
   maximization <- attr(ds, 'maximization')
@@ -874,8 +930,8 @@ fast_RT_samples <- function(RT_mat, target, maximization = F) {
 #' @rdname get_FV_summary
 #' @export
 #'
-get_FV_summary.DataSet <- function(ds, runtime, ...) {
-  data <- ds$FV
+get_FV_summary.DataSet <- function(ds, runtime, include_geom_mean = F, ...) {
+  data <- get_FV(ds)
   NC <- ncol(data)
   NR <- nrow(data)
   ID <- get_id(ds)
@@ -900,13 +956,19 @@ get_FV_summary.DataSet <- function(ds, runtime, ...) {
   matched <- sapply(runtime, function(r) rev(idx[r >= RT])[1])
   data <- data[matched, , drop = FALSE]
 
-  cbind(ID, runtime, NC,
+  dt <- cbind(ID, runtime, NC,
         apply(data, 1, .mean),
         apply(data, 1, .median),
         apply(data, 1, .sd),
         as.data.table(t(apply(data, 1, IOHanalyzer_env$C_quantile)))) %>%
     set_colnames(c('ID', 'runtime', 'runs', 'mean', 'median', 'sd',
                     paste0(getOption("IOHanalyzer.quantiles") * 100, '%')))
+
+  if (include_geom_mean) {
+    dt <- cbind(dt, apply(data, 1, function(x) {exp(mean(log(x)))} ))
+    setnames(dt, 'V2', 'geometric mean')
+  }
+  return(dt)
 }
 
 #' @rdname get_FV_sample
@@ -915,7 +977,7 @@ get_FV_summary.DataSet <- function(ds, runtime, ...) {
 #' @export
 #'
 get_FV_sample.DataSet <- function(ds, runtime, output = 'wide', ...) {
-  data <- ds$FV
+  data <- get_FV(ds)
   N <- ncol(data)
   n_row <- nrow(data)
   ID <- get_id(ds)
@@ -952,12 +1014,12 @@ get_PAR_name.DataSet <- function(ds, which = 'by_FV') {
 #' @export
 get_PAR_summary.DataSet <- function(ds, idxValue, parId = 'all', which = 'by_FV', ...) {
   if (which == 'by_FV') {
-    RefValues <- as.numeric(rownames(ds$RT))
+    RefValues <- as.numeric(rownames(get_RT(ds)))
     ds_par <- ds$PAR$by_FV
     idx_name <- 'target'
   }
   else if (which == 'by_RT') {
-    RefValues <- as.numeric(rownames(ds$FV))
+    RefValues <- as.numeric(rownames(get_FV(ds)))
     ds_par <- ds$PAR$by_RT
     idx_name <- 'runtime'
   }
@@ -1012,12 +1074,12 @@ get_PAR_sample.DataSet <- function(ds, idxValue, parId = 'all', which = 'by_FV',
                                    output = 'wide', ...) {
   N <- length(attr(ds, 'instance'))
   if (which == 'by_FV') {
-    RefValues <- as.numeric(rownames(ds$RT))
+    RefValues <- as.numeric(rownames(get_RT(ds)))
     ds_par <- ds$PAR$by_FV
     idx_name <- 'target'
   }
   else if (which == 'by_RT') {
-    RefValues <- as.numeric(rownames(ds$FV))
+    RefValues <- as.numeric(rownames(get_FV(ds)))
     ds_par <- ds$PAR$by_RT
     idx_name <- 'runtime'
   }
@@ -1069,3 +1131,32 @@ get_id.DataSet <- function(ds, ...) {
   }
   return(unique(temp))
 }
+
+#' @rdname get_FV
+#' @export
+get_FV.DataSet <- function(ds, ...) {
+  if (isTRUE(attr(ds, 'constrained')) && !is.null(getOption("IOHanalyzer.Violation_Function"))) {
+    FV <- getOption("IOHanalyzer.Violation_Function",
+                     default = function(x,y) {x}
+                     )(ds$FV_raw_mat, ds$PAR$by_RT$violation)
+    if (attr(ds, 'maximization'))
+      return(do.call(cbind, lapply(seq(ncol(FV)), function(x) cummax(FV[,x]))))
+    return(do.call(cbind, lapply(seq(ncol(FV)), function(x) cummin(FV[,x]))))
+  } else return(ds$FV)
+}
+
+#' @rdname get_RT
+#' @export
+get_RT.DataSet <- function(ds, ...) {
+  if (isTRUE(attr(ds, 'constrained')) && !is.null(getOption("IOHanalyzer.Violation_Function"))) {
+    data <- getOption("IOHanalyzer.Violation_Function",
+                      default = function(x,y) {x}
+    )(ds$FV_raw_mat, ds$PAR$by_RT$violation)
+    FV <- unique(sort(data, decreasing = !attr(ds, 'maximization')))
+    index <- as.numeric(rownames(data))
+    RT <- c_align_running_time_matrix(data, FV, as.numeric(index), attr(ds, 'maximization'))
+    rownames(RT) <- FV
+    return(RT)
+  } else return(ds$RT)
+}
+
